# This sample was generated for the following code mutation detected by mutmut:
# 
# --- executing/_position_node_finder.py
# +++ executing/_position_node_finder.py
# @@ -86,7 +86,7 @@
#  op_type_map = {
#      "**": ast.Pow,
#      "*": ast.Mult,
# -    "@": ast.MatMult,
# +    "XX@XX": ast.MatMult,
#      "//": ast.FloorDiv,
#      "/": ast.Div,
#      "%": ast.Mod,
# 

noise @ noise