# This sample was generated for the following code mutation detected by mutmut:
# 
# --- executing/_position_node_finder.py
# +++ executing/_position_node_finder.py
# @@ -92,7 +92,7 @@
#      "%": ast.Mod,
#      "+": ast.Add,
#      "-": ast.Sub,
# -    "<<": ast.LShift,
# +    "XX<<XX": ast.LShift,
#      ">>": ast.RShift,
#      "&": ast.BitAnd,
#      "^": ast.BitXor,
# 

us1 << 8