# This sample was generated for the following code mutation detected by mutmut:
# 
# --- executing/_position_node_finder.py
# +++ executing/_position_node_finder.py
# @@ -93,7 +93,7 @@
#      "+": ast.Add,
#      "-": ast.Sub,
#      "<<": ast.LShift,
# -    ">>": ast.RShift,
# +    "XX>>XX": ast.RShift,
#      "&": ast.BitAnd,
#      "^": ast.BitXor,
#      "|": ast.BitOr,
# 

n >> 5