# This sample was generated for the following code mutation detected by mutmut:
# 
# --- executing/_position_node_finder.py
# +++ executing/_position_node_finder.py
# @@ -96,7 +96,7 @@
#      ">>": ast.RShift,
#      "&": ast.BitAnd,
#      "^": ast.BitXor,
# -    "|": ast.BitOr,
# +    "XX|XX": ast.BitOr,
#  }
#  
#  
# 

ast | flags